==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/so-SO/localizations.php <==
<?php

return [

    'select_language' => 'Dooro luqad',
    'languages' => [
        'en-US'=> 'Ingiriis, US',
        'en-GB'=> 'Ingiriis, UK',
        'am-ET' => 'Amharic',
        'af-ZA'=> 'Afrikaan',
        'ar-SA'=> 'Carabi',
        'bg-BG'=> 'Bulgaariya',
        'zh-CN'=> 'Shiinees La Fududeeyay',
        'zh-TW'=> 'Dhaqanka Shiinaha',
        'ca-ES' => 'Catalan',
        'hr-HR'=> 'Croatian',
        'cs-CZ'=> 'Czech',
        'da-DK'=> 'Danish',
        'nl-NL'=> 'Holland',
        'en-ID'=> 'Ingiriis, Indonesia',
        'et-EE'=> 'Istooniyaan',
        'fil-PH'=> 'Filibiin',
        'fi-FI'=> 'Finnish',
        'fr-FR'=> 'Faransiis',
        'de-DE'=> 'Jarmal',
        'de-if'=> 'Jarmal (aan rasmi ahayn)',
        'el-GR'=> 'Giriig',
        'he-IL'=> 'Cibraaniga',
        'hu-HU'=> 'Hungarian',
        'is-IS' => 'Icelandic',
        'id-ID'=> 'Indonesian',
        'ga-IE'=> 'Irish',
        'it-IT'=> 'Talyaani',
        'ja-JP'=> 'Jabbaan',
        'km-KH'=>'Khmer',
        'ko-KR'=> 'Kuuriyaan',
        'lt-LT'=>'Lithuanian',
        'lv-LV'=> 'Latvia',
        'mk-MK'=> 'Masedooniyaan',
        'ms-MY'=> 'Malaay',
        'mi-NZ'=> 'Maori',
        'mn-MN'=> 'Mongoliyaan',
        'no-NO'=> 'Noorwiiji',
        'fa-IR'=> 'Faaris',
        'pl-PL'=> 'Boolish',
        'pt-PT'=> 'Boortaqiis',
        'pt-BR'=> 'Boortaqiis, Baraasiil',
        'ro-RO'=> 'Romanian',
        'ru-RU'=> 'Ruush',
        'sr-CS' => 'Seerbiyaan (Laatiin)',
        'sk-SK'=> 'Slovak',
        'sl-SI'=> 'Islovenian',
        'so-SO'=> 'Somali',
        'es-ES'=> 'Isbaanish',
        'es-CO'=> 'Isbaanish, Kolombiya',
        'es-MX'=> 'Isbaanish, Mexico',
        'es-VE'=> 'Isbaanish, Venezuela',
        'sv-SE'=> 'Iswidish',
        'tl-PH'=> 'Tagalog',
        'ta-IN'=> 'Tamil',
        'th-TH'=> 'Thai',
        'tr-TR'=> 'Turki',
        'uk-UA'=> 'Yukreeniyaan',
        'vi-VN'=> 'Fiyatnaamiis',
        'cy-GB'=> 'Welsh',
        'zu-ZA'=> 'Zulu',
    ],

    'select_country' => 'Dal dooro',
    
    'countries' => [
        'AC'=>'Jasiiradda Ascension',
        'AD'=>'Andorra',
        'AE'=>'Imaaraadka Carabta',
        'AF'=>'Afgaanistaan',
        'AG'=>'Antigua iyo Barbuda',
        'AI'=>'Anguilla',
        'AL'=>'Albania',
        'AM'=>'Armeeniya',
        'AN'=>'Netherlands Antilles',
        'AO'=>'Angola',
        'AQ'=>'Antarctica',
        'AR'=>'Argentina',
        'AS'=>'Maraykanka Samoa',
        'AT'=>'Awstariya',
        'AU'=>'Australia',
        'AW'=>'Aruba',
        'AX'=>'Ãƒâ€šÃ‚Â dhul',
        'AZ'=>'Asarbayjan',
        'BA'=>'Bosnia iyo Herzegovina',
        'BB'=>'Barbados',
        'BE'=>'Belgium',
        'BD'=>'Bangladesh',
        'BF'=>'Burkina Faso',
        'BG'=>'Bulgaariya',
        'BH'=>'Baxrayn',
        'BI'=>'Burundi',
        'BJ'=>'Benin',
        'BM'=>'Bermuuda',
        'BN'=>'Brunei Darussalam',
        'BO'=>'Bolivia',
        'BR'=>'Brazil',
        'BS'=>'Bahamas',
        'BT'=>'Butan',
        'BV'=>'Jasiiradda Bouvet',
        'BW'=>'Botswana',
        'BY'=>'Belarus',
        'BZ'=>'Belize',
        'CA'=>'Kanada',
        'CC'=>'Jasiiradaha Cocos (Keeling).',
        'CD'=>'Kongo (Jamhuuriyadda Dimuqraadiga ah)',
        'CF'=>'Jamhuuriyadda Afrikada Dhexe',
        'CG'=>'Kongo (Jamhuuriyadda)',
        'CH'=>'Switzerland',
        'CI'=>'Côte d\'Ivoire',
        'CK'=>'Jasiiradaha Cook',
        'CL'=>'Chile',
        'CM'=>'Cameroon',
        'CN'=>'Jamhuuriyadda Dadka ee Shiinaha',
        'CO'=>'Kolombiya',
        'CR'=>'Costa Rica',
        'CU'=>'Kuuba',
        'CV'=>'Cape Verde',
        'CX'=>'Christmas Island',
        'CY'=>'Qubrus',
        'CZ'=>'Czech Republic',
        'DE'=>'Jarmalka',
        'DJ'=>'Jabuuti',
        'DK'=>'Denmark',
        'DM'=>'Dominika',
        'DO'=>'Jamhuuriyadda Dominikan',
        'DZ'=>'Algeria',
        'EC'=>'Ecuador',
        'EE'=>'Estonia',
        'EG'=>'Masar',
        'ER'=>'Eritrea',
        'ES'=>'Isbayn',
        'ET'=>'Itoobiya',
        'EU'=>'Midowga Yurub',
        'FI'=>'Finland',
        'FJ'=>'Fiji',
        'FK'=>'Jasiiradaha Falkland (Malvinas)',
        'FM'=>'Micronesia, Dawlada Dhexe',
        'FO'=>'Jasiiradaha Faroe',
        'FR'=>'Faransiiska',
        'GA'=>'Gabon',
        'GD'=>'Grenada',
        'GE'=>'Georgia',
        'GF'=>'Guiana Faransiis',
        'GG'=>'Guernsey',
        'GH'=>'Ghana',
        'GI'=>'Gibraltar',
        'GL'=>'Greenland',
        'GM'=>'Gambia',
        'GN'=>'Guinea',
        'GP'=>'Guadeloupe',
        'GQ'=>'Equatorial Guinea',
        'GR'=>'Giriiga',
        'GS'=>'Koonfurta Georgia iyo Koonfurta Jasiiradaha Sandwich',
        'GT'=>'Guatemala',
        'GU'=>'Guam',
        'GW'=>'Guinea-Bissau',
        'GY'=>'Guyana',
        'HK'=>'Hong Kong',
        'HM'=>'Maqal iyo Mc Donald Islands',
        'HN'=>'Honduras',
        'HR'=>'Croatia (magaca deegaanka: Hrvatska)',
        'HT'=>'Haiti',
        'HU'=>'Hungary',
        'ID'=>'Indonesia',
        'IE'=>'Ireland',
        'IL'=>'Israa\'iil',
        'IM'=>'Jasiiradda Man',
        'IN'=>'Hindiya',
        'IO'=>'Dhulka Badweynta Hindiya ee Ingiriiska',
        'IQ'=>'Ciraaq',
        'IR'=>'Iran, Jamhuuriyadda Islaamiga ah ee',
        'IS'=>'Iceland',
        'IT'=>'Talyaaniga',
        'JE'=>'Jersey',
        'JM'=>'Jamaica',
        'JO'=>'Jordan',
        'JP'=>'Japan',
        'KE'=>'Kenya',
        'KG'=>'Kyrgyzstan',
        'KH'=>'Cambodia',
        'KI'=>'Kiribati',
        'KM'=>'Komoros',
        'KN'=>'Saint Kitts iyo Nevis',
        'KR'=>'Kuuriya, Jamhuuriyadda',
        'KW'=>'Kuwait',
        'KY'=>'Jasiiradaha Cayman',
        'KZ'=>'Kazakhstan',
        'LA'=>'Jamhuuriyadda Dimuqraadiga Dadka Lao',
        'LB'=>'Lubnaan',
        'LC'=>'Saint Lucia',
        'LI'=>'Liechtenstein',
        'LK'=>'Sirilaanka',
        'LR'=>'Laybeeriya',
        'LS'=>'Lesotho',
        'LT'=>'Lithuania',
        'LU'=>'Luxembourg',
        'LV'=>'Latfiya',
        'LY'=>'Liibiya Carab Jaamaca',
        'MA'=>'Morocco',
        'MC'=>'Monaco',
        'MD'=>'Moldova, Jamhuuriyadda',
        'ME'=>'Montenegro',
        'MG'=>'Madagascar',
        'MH'=>'Jasiiradaha Marshall',
        'MK'=>'Macedonia, Jamhuuriyadda Yugoslavia hore ee',
        'ML'=>'Maali',
        'MM'=>'Myanmar',
        'MN'=>'Mongolia',
        'MO'=>'Macau',
        'MP'=>'Waqooyiga Mariana Islands',
        'MQ'=>'Martinique',
        'MR'=>'Mauritania',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauritius',
        'MV'=>'Maldives',
        'MW'=>'Malawi',
        'MX'=>'Mexico',
        'MY'=>'Malaysia',
        'MZ'=>'Mozambique',
        'NA'=>'Namibia',
        'NC'=>'New Caledonia',
        'NE'=>'Niger',
        'NF'=>'Jasiiradda Norfolk',
        'NG'=>'Nigeria',
        'NI'=>'Nicaragua',
        'NL'=>'Nederlaan',
        'NO'=>'Norway',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Niue',
        'NZ'=>'New Zealand',
        'OM'=>'Cumaan',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'Faransiiska Polynesia',
        'PG'=>'Papua New Guinea',
        'PH'=>'Filibiin, Jamhuuriyadda',
        'PK'=>'Pakistan',
        'PL'=>'Poland',
        'PM'=>'St. Pierre iyo Miquelon',
        'PN'=>'Pitcairn',
        'PR'=>'Puerto Rico',
        'PS'=>'Falastiin',
        'PT'=>'Portugal',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Qatar',
        'RE'=>'Isu imaatinka',
        'RO'=>'Romania',
        'RS'=>'Seerbiya',
        'RU'=>'Xiriirka Ruushka',
        'RW'=>'Rwanda',
        'SA'=>'Sacuudi Carabiya',
        'UK'=>'Scotland',
        'SB'=>'Solomon Islands',
        'SC'=>'Seychelles',
        'SS'=>'Koonfurta Suudaan',
        'SD'=>'Suudaan',
        'SE'=>'Iswiidhan',
        'SG'=>'Singapore',
        'SH'=>'St. Helena',
        'SI'=>'Slovenia',
        'SJ'=>'Svalbard iyo Jan Mayen Islands',
        'SK'=>'Slovakia (Jamhuuriyadda Slovakia)',
        'SL'=>'Siiraaliyoon',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Soomaaliya',
        'SR'=>'Suriname',
        'ST'=>'Sao Tome iyo Principe',
        'SU'=>'Midowgii Sofyeeti',
        'SV'=>'El Salvador',
        'SY'=>'Jamhuuriyadda Carabta Suuriya',
        'SZ'=>'Swaziland',
        'TC'=>'Turki iyo Jasiiradaha Caicos',
        'TD'=>'Jaad',
        'TF'=>'Dhulka Koonfureed ee Faransiiska',
        'TG'=>'Togo',
        'TH'=>'Thailand',
        'TJ'=>'Tajikistan',
        'TK'=>'Tokelau',
        'TI'=>'Bariga Timor',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunisia',
        'TO'=>'Tonga',
        'TP'=>'East Timor (code hore)',
        'TR'=>'Turkiga',
        'TT'=>'Trinidad iyo Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Taiwan',
        'TZ'=>'Tansaaniya, jamhuuriyada midoobay',
        'UA'=>'Ukraine',
        'UG'=>'Uganda',
        'UK'=>'Boqortooyada Ingiriiska',
        'US'=>'Maraykanka',
        'UM'=>'Jasiiradaha ka baxsan Maraykanka',
        'UY'=>'Uruguay',
        'UZ'=>'Uzbekistan',
        'VA'=>'Gobolka Vatican-ka (Holy See)',
        'VC'=>'Saint Vincent iyo Grenadines',
        'VE'=>'Venezuela',
        'VG'=>'Jasiiradaha Virgin (Ingiriis)',
        'VI'=>'Jasiiradaha Virgin (US)',
        'VN'=>'Fiitnaam',
        'VU'=>'Vanuatu',
        'WF'=>'Wallis iyo Futuna Islands',
        'WS'=>'Samoa',
        'YE'=>'Yemen',
        'YT'=>'Mayotte',
        'ZA'=>'Koonfur Afrika',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabwe',
    ],
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/so-SO/localizations.php <==
<?php

return [

    'select_language' => 'Select a Language',
    'languages' => [
        'en-US'=> 'Ingiriis, US',
        'en-GB'=> 'Ingiriis, UK',
        'am-ET' => 'Amharic',
        'af-ZA'=> 'Afrikaan',
        'ar-SA'=> 'Carabi',
        'bg-BG'=> 'Bulgaariya',
        'zh-CN'=> 'Shiinees La Fududeeyay',
        'zh-TW'=> 'Dhaqanka Shiinaha',
        'ca-ES' => 'Catalan',
        'hr-HR'=> 'Croatian',
        'cs-CZ'=> 'Czech',
        'da-DK'=> 'Danish',
        'nl-NL'=> 'Holland',
        'en-ID'=> 'Ingiriis, Indonesia',
        'et-EE'=> 'Istooniyaan',
        'fil-PH'=> 'Filibiin',
        'fi-FI'=> 'Finnish',
        'fr-FR'=> 'Faransiis',
        'de-DE'=> 'Jarmal',
        'de-if'=> 'Jarmal (aan rasmi ahayn)',
        'el-GR'=> 'Giriig',
        'he-IL'=> 'Cibraaniga',
        'hu-HU'=> 'Hungarian',
        'is-IS' => 'Icelandic',
        'id-ID'=> 'Indonesian',
        'ga-IE'=> 'Irish',
        'it-IT'=> 'Talyaani',
        'ja-JP'=> 'Jabbaan',
        'km-KH'=>'Khmer',
        'ko-KR'=> 'Kuuriyaan',
        'lt-LT'=>'Lithuanian',
        'lv-LV'=> 'Latvia',
        'mk-MK'=> 'Masedooniyaan',
        'ms-MY'=> 'Malaay',
        'mi-NZ'=> 'Maori',
        'mn-MN'=> 'Mongoliyaan',
        //'no-NO'=> 'Norwegian',
        'nb-NO'=> 'Norwegian Bokmål',
        //'nn-NO'=> 'Norwegian Nynorsk',
        'fa-IR'=> 'Faaris',
        'pl-PL'=> 'Boolish',
        'pt-PT'=> 'Boortaqiis',
        'pt-BR'=> 'Boortaqiis, Baraasiil',
        'ro-RO'=> 'Romanian',
        'ru-RU'=> 'Ruush',
        'sr-CS' => 'Seerbiyaan (Laatiin)',
        'sk-SK'=> 'Slovak',
        'sl-SI'=> 'Islovenian',
        'so-SO'=> 'Somali',
        'es-ES'=> 'Isbaanish',
        'es-CO'=> 'Isbaanish, Kolombiya',
        'es-MX'=> 'Isbaanish, Mexico',
        'es-VE'=> 'Isbaanish, Venezuela',
        'sv-SE'=> 'Iswidish',
        'tl-PH'=> 'Tagalog',
        'ta-IN'=> 'Tamil',
        'th-TH'=> 'Thai',
        'tr-TR'=> 'Turki',
        'uk-UA'=> 'Yukreeniyaan',
        'vi-VN'=> 'Fiyatnaamiis',
        'cy-GB'=> 'Welsh',
        'zu-ZA'=> 'Zulu',
    ],

    'select_country' => 'Select a Country',
    
    'countries' => [
        'AC'=>'Jasiiradda Ascension',
        'AD'=>'Andorra',
        'AE'=>'Imaaraadka Carabta',
        'AF'=>'Afgaanistaan',
        'AG'=>'Antigua iyo Barbuda',
        'AI'=>'Anguilla',
        'AL'=>'Albania',
        'AM'=>'Armeeniya',
        'AN'=>'Netherlands Antilles',
        'AO'=>'Angola',
        'AQ'=>'Antarctica',
        'AR'=>'Argentina',
        'AS'=>'Maraykanka Samoa',
        'AT'=>'Awstariya',
        'AU'=>'Australia',
        'AW'=>'Aruba',
        'AX'=>'Ãƒâ€šÃ‚Â dhul',
        'AZ'=>'Asarbayjan',
        'BA'=>'Bosnia iyo Herzegovina',
        'BB'=>'Barbados',
        'BE'=>'Belgium',
        'BD'=>'Bangladesh',
        'BF'=>'Burkina Faso',
        'BG'=>'Bulgaariya',
        'BH'=>'Baxrayn',
        'BI'=>'Burundi',
        'BJ'=>'Benin',
        'BM'=>'Bermuuda',
        'BN'=>'Brunei Darussalam',
        'BO'=>'Bolivia',
        'BR'=>'Brazil',
        'BS'=>'Bahamas',
        'BT'=>'Butan',
        'BV'=>'Jasiiradda Bouvet',
        'BW'=>'Botswana',
        'BY'=>'Belarus',
        'BZ'=>'Belize',
        'CA'=>'Kanada',
        'CC'=>'Jasiiradaha Cocos (Keeling)',
        'CD'=>'Kongo (Jamhuuriyadda Dimuqraadiga ah)',
        'CF'=>'Jamhuuriyadda Afrikada Dhexe',
        'CG'=>'Kongo (Jamhuuriyadda)',
        'CH'=>'Switzerland',
        'CI'=>'Côte d\'Ivoire',
        'CK'=>'Jasiiradaha Cook',
        'CL'=>'Chile',
        'CM'=>'Cameroon',
        'CN'=>'Jamhuuriyadda Dadka ee Shiinaha',
        'CO'=>'Kolombiya',
        'CR'=>'Costa Rica',
        'CU'=>'Kuuba',
        'CV'=>'Cape Verde',
        'CX'=>'Christmas Island',
        'CY'=>'Qubrus',
        'CZ'=>'Czech Republic',
        'DE'=>'Jarmalka',
        'DJ'=>'Jabuuti',
        'DK'=>'Denmark',
        'DM'=>'Dominika',
        'DO'=>'Jamhuuriyadda Dominikan',
        'DZ'=>'Algeria',
        'EC'=>'Ecuador',
        'EE'=>'Estonia',
        'EG'=>'Masar',
        'GB-ENG'=>'England',
        'ER'=>'Eritrea',
        'ES'=>'Isbayn',
        'ET'=>'Itoobiya',
        'EU'=>'Midowga Yurub',
        'FI'=>'Finland',
        'FJ'=>'Fiji',
        'FK'=>'Jasiiradaha Falkland (Malvinas)',
        'FM'=>'Micronesia, Dawlada Dhexe',
        'FO'=>'Jasiiradaha Faroe',
        'FR'=>'Faransiiska',
        'GA'=>'Gabon',
        'GD'=>'Grenada',
        'GE'=>'Georgia',
        'GF'=>'Guiana Faransiis',
        'GG'=>'Guernsey',
        'GH'=>'Ghana',
        'GI'=>'Gibraltar',
        'GL'=>'Greenland',
        'GM'=>'Gambia',
        'GN'=>'Guinea',
        'GP'=>'Guadeloupe',
        'GQ'=>'Equatorial Guinea',
        'GR'=>'Giriiga',
        'GS'=>'Koonfurta Georgia iyo Koonfurta Jasiiradaha Sandwich',
        'GT'=>'Guatemala',
        'GU'=>'Guam',
        'GW'=>'Guinea-Bissau',
        'GY'=>'Guyana',
        'HK'=>'Hong Kong',
        'HM'=>'Maqal iyo Mc Donald Islands',
        'HN'=>'Honduras',
        'HR'=>'Croatia (magaca deegaanka: Hrvatska)',
        'HT'=>'Haiti',
        'HU'=>'Hungary',
        'ID'=>'Indonesia',
        'IE'=>'Ireland',
        'IL'=>'Israa\'iil',
        'IM'=>'Jasiiradda Man',
        'IN'=>'Hindiya',
        'IO'=>'Dhulka Badweynta Hindiya ee Ingiriiska',
        'IQ'=>'Ciraaq',
        'IR'=>'Iran, Jamhuuriyadda Islaamiga ah ee',
        'IS'=>'Iceland',
        'IT'=>'Talyaaniga',
        'JE'=>'Jersey',
        'JM'=>'Jamaica',
        'JO'=>'Jordan',
        'JP'=>'Japan',
        'KE'=>'Kenya',
        'KG'=>'Kyrgyzstan',
        'KH'=>'Cambodia',
        'KI'=>'Kiribati',
        'KM'=>'Komoros',
        'KN'=>'Saint Kitts iyo Nevis',
        'KR'=>'Kuuriya, Jamhuuriyadda',
        'KW'=>'Kuwait',
        'KY'=>'Jasiiradaha Cayman',
        'KZ'=>'Kazakhstan',
        'LA'=>'Jamhuuriyadda Dimuqraadiga Dadka Lao',
        'LB'=>'Lubnaan',
        'LC'=>'Saint Lucia',
        'LI'=>'Liechtenstein',
        'LK'=>'Sirilaanka',
        'LR'=>'Laybeeriya',
        'LS'=>'Lesotho',
        'LT'=>'Lithuania',
        'LU'=>'Luxembourg',
        'LV'=>'Latfiya',
        'LY'=>'Liibiya',
        'MA'=>'Morocco',
        'MC'=>'Monaco',
        'MD'=>'Moldova, Jamhuuriyadda',
        'ME'=>'Montenegro',
        'MG'=>'Madagascar',
        'MH'=>'Jasiiradaha Marshall',
        'MK'=>'Macedonia, Jamhuuriyadda Yugoslavia hore ee',
        'ML'=>'Maali',
        'MM'=>'Myanmar',
        'MN'=>'Mongolia',
        'MO'=>'Macau',
        'MP'=>'Waqooyiga Mariana Islands',
        'MQ'=>'Martinique',
        'MR'=>'Mauritania',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauritius',
        'MV'=>'Maldives',
        'MW'=>'Malawi',
        'MX'=>'Mexico',
        'MY'=>'Malaysia',
        'MZ'=>'Mozambique',
        'NA'=>'Namibia',
        'NC'=>'New Caledonia',
        'NE'=>'Niger',
        'NF'=>'Jasiiradda Norfolk',
        'NG'=>'Nigeria',
        'NI'=>'Nicaragua',
        'NL'=>'Nederlaan',
        'GB-NIR' => 'Northern Ireland',
        'NO'=>'Norway',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Niue',
        'NZ'=>'New Zealand',
        'OM'=>'Cumaan',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'Faransiiska Polynesia',
        'PG'=>'Papua New Guinea',
        'PH'=>'Filibiin, Jamhuuriyadda',
        'PK'=>'Pakistan',
        'PL'=>'Poland',
        'PM'=>'St. Pierre iyo Miquelon',
        'PN'=>'Pitcairn',
        'PR'=>'Puerto Rico',
        'PS'=>'Falastiin',
        'PT'=>'Portugal',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Qatar',
        'RE'=>'Isu imaatinka',
        'RO'=>'Romania',
        'RS'=>'Seerbiya',
        'RU'=>'Xiriirka Ruushka',
        'RW'=>'Rwanda',
        'SA'=>'Sacuudi Carabiya',
        'GB-SCT'=>'Scotland',
        'SB'=>'Solomon Islands',
        'SC'=>'Seychelles',
        'SS'=>'Koonfurta Suudaan',
        'SD'=>'Suudaan',
        'SE'=>'Iswiidhan',
        'SG'=>'Singapore',
        'SH'=>'St. Helena',
        'SI'=>'Slovenia',
        'SJ'=>'Svalbard iyo Jan Mayen Islands',
        'SK'=>'Slovakia (Jamhuuriyadda Slovakia)',
        'SL'=>'Siiraaliyoon',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Soomaaliya',
        'SR'=>'Suriname',
        'ST'=>'Sao Tome iyo Principe',
        'SU'=>'Midowgii Sofyeeti',
        'SV'=>'El Salvador',
        'SY'=>'Jamhuuriyadda Carabta Suuriya',
        'SZ'=>'Swaziland',
        'TC'=>'Turki iyo Jasiiradaha Caicos',
        'TD'=>'Jaad',
        'TF'=>'Dhulka Koonfureed ee Faransiiska',
        'TG'=>'Togo',
        'TH'=>'Thailand',
        'TJ'=>'Tajikistan',
        'TK'=>'Tokelau',
        'TI'=>'Bariga Timor',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunisia',
        'TO'=>'Tonga',
        'TP'=>'East Timor (code hore)',
        'TR'=>'Turkiga',
        'TT'=>'Trinidad iyo Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Taiwan',
        'TZ'=>'Tansaaniya, jamhuuriyada midoobay',
        'UA'=>'Ukraine',
        'UG'=>'Uganda',
        'UK'=>'Boqortooyada Ingiriiska',
        'US'=>'Maraykanka',
        'UM'=>'Jasiiradaha ka baxsan Maraykanka',
        'UY'=>'Uruguay',
        'UZ'=>'Uzbekistan',
        'VA'=>'Gobolka Vatican-ka (Holy See)',
        'VC'=>'Saint Vincent iyo Grenadines',
        'VE'=>'Venezuela',
        'VG'=>'Jasiiradaha Virgin (Ingiriis)',
        'VI'=>'Jasiiradaha Virgin (US)',
        'VN'=>'Fiitnaam',
        'VU'=>'Vanuatu',
        'GB-WLS' =>'Wales',
        'WF'=>'Wallis iyo Futuna Islands',
        'WS'=>'Samoa',
        'YE'=>'Yemen',
        'YT'=>'Mayotte',
        'ZA'=>'Koonfur Afrika',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabwe',
    ],
];
